{% load static %}
<!-- Start FontAwesome CSS from aa-gdpr -->
<link rel="stylesheet" href="{% static 'aagdpr/ajax/libs/font-awesome/6.4.2/css/all.min.css' %}" integrity="sha512-z3gLpd7yknf1YoNbCzqRKc4qyor8gaKU1qmn+CShxbuBusANI9QpRohGBreCFkKxLhei6S9CQXFEbbKuqLg0DA==">
<!-- End FontAwesome CSS from aa-gdpr -->
