// Alliance Auth customisations of the bootswatch Darkly theme
// To build a new CSS file you need to `npm install -g less less-plugin-clean-css`
// Then `lessc --clean-css="--advanced" darkly.less darkly.min.css`

@import "https://raw.githubusercontent.com/thomaspark/bootswatch/v3/bower_components/bootstrap/less/bootstrap.less";
@import "https://raw.githubusercontent.com/thomaspark/bootswatch/v3/darkly/variables.less";
@import "bootswatch.less";
@import "../bootstrap-locals.less";
@import "../flatly-shared.less";
