{% load static %}
<!-- Start X-editable JS from aa-gdpr -->
<script src="{% static 'aagdpr/ajax/libs/x-editable/1.5.1/js/bootstrap-editable.min.js' %}" integrity="sha512-Mvqhe3YIUElH6VT0CFmUeRgYMrLvCGd2mvYCnJOf2nL9FvRBK74qRgTn7u0zSqA5cHiGxy83bwuhl1ASbS9M/w=="></script>
<!-- End X-editable JS from aa-gdpr -->
