{% load static %}
<!-- Start Datatables-css from aa-gdpr -->
<link rel="stylesheet" href="{% static 'aagdpr/ajax/libs/datatables.net/1.13.7/css/dataTables.bootstrap5.min.css' %}" integrity="sha512-TYucTg2DTKx05NRJKSS3IoVrDPfhuNYCw30zPRFOYgE1OD1j2VQQ+iCZj2mG8vNcXStFGdV+1XBLOWSij+P/0w==">
<!-- End Datatables-css from aa-gdpr -->
