{% load static %}
<!-- Start jQuery-DateTimePicker CSS from aa-gdpr -->
<link rel="stylesheet" href="{% static 'aagdpr/ajax/libs/jquery-datetimepicker/2.5.20/jquery.datetimepicker.min.css' %}" integrity="sha512-f0tzWhCwVFS3WeYaofoLWkTP62ObhewQ1EZn65oSYDZUg1+CyywGKkWzm8BxaJj5HGKI72PnMH9jYyIFz+GH7g==">
<!-- End jQuery-DateTimePicker CSS from aa-gdpr -->
