{% load static %}
<!-- Start jQuery-Visibility JS from aa-gdpr -->
<script src="{% static 'aagdpr/ajax/libs/jquery-visibility/1.0.11/jquery-visibility.min.js' %}" integrity="sha512-kL8M4N4KLFJ4ydyfbBiXU1InCR6zs8jm8NR1BXykgFmMhVO3RS9bvoMHnVwoPe+i6NRvfydNlweatKee85Df3A=="></script>
<!-- End jQuery-Visibility JS from aa-gdpr -->
