{% load static %}
<!-- Start Datatables-css from aa-gdpr -->
<link rel="stylesheet" href="{% static 'aagdpr/ajax/libs/datatables.net/1.13.7/css/dataTables.bootstrap.min.css' %}" integrity="sha512-FpBNY1viXknqRK4I7V53wLHmPfDYMOkBkuq84aGEW2x5rHl0ynd609oedZXA0+ccSTjhIQl6NDiDvMxhSWs0Jg==">
<!-- End Datatables-css from aa-gdpr -->
