{% load static %}
<!-- Start jQuery UI JS from aa-gdpr -->
<script src="{% static 'aagdpr/ajax/libs/jquery-ui/1.13.2/js/jquery-ui.min.js' %}" integrity="sha512-/nyLzk/uCFXd+GWoAhNjc9woFKYG7+SOHg/y8tJ/5jZRzk5LHRHoRLZiPnxJboBFJqI38pqSJujINlGJ1s2khQ==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<!-- End jQuery UI JS from aa-gdpr -->
