{% load static %}
<!-- Start Datatables-js from aa-gdpr -->
<script src="{% static 'aagdpr/ajax/libs/datatables.net/1.13.7/js/jquery.dataTables.min.js' %}"
        integrity="sha512-7ilNMAgbuWXHILZQninNCl4LNo2OMW39hq984jpRgyUPlV2dy94yVoOJV1tQjohdqZ+2e5Ek2gEbKqWB4A8dRg=="
        crossorigin="anonymous"
        referrerpolicy="no-referrer"></script>
<script src="{% static 'aagdpr/ajax/libs/datatables.net/1.13.7/js/dataTables.bootstrap5.min.js' %}"
        integrity="sha512-zw34c1fnMeY29qzodeC+GGKfyQQ7hN+a9yjGnIAZbkPPn/Xeh8Z46uea/fjq5Mwsp4bxvGKfJrTNnh/GdIZJ1g=="
        crossorigin="anonymous"
        referrerpolicy="no-referrer"></script>
<!-- End Datatables-js from aa-gdpr -->
