{% load static %}
<!-- Start Clipboard.js js from aa-gdpr -->
<script src="{% static 'aagdpr/ajax/libs/clipboard.js/2.0.11/clipboard.min.js' %}"
        integrity='sha512-7O5pXpc0oCRrxk8RUfDYFgn0nO1t+jLuIOQdOMRp4APB7uZ4vSjspzp5y6YDtDs4VzUSTbWzBFZ/LKJhnyFOKw=='
        crossorigin='anonymous'
        referrerpolicy="no-referrer"></script>
<!-- End Clipboard.js js from aa-gdpr -->
