{% load static %}
<!-- Start jQuery JS from aa-gdpr -->
<script src="{% static 'aagdpr/ajax/libs/jquery/3.7.1/jquery.min.js' %}" integrity="sha512-v2CJ7UaYy4JwqLDIrZUI/4hqeoQieOmAZNXBeQyjo21dadnwR+8ZaIJVT8EE2iyI61OV8e6M8PP2/4hpQINQ/g==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<!-- End jQuery JS from aa-gdpr -->
