{% load static %}
<!-- Start jQuery-DateTimePicker JS from aa-gdpr -->
<script src="{% static 'aagdpr/ajax/libs/jquery-datetimepicker/2.5.20/jquery.datetimepicker.full.min.js' %}" integrity="sha512-AIOTidJAcHBH2G/oZv9viEGXRqDNmfdPVPYOYKGy3fti0xIplnlgMHUGfuNRzC6FkzIo0iIxgFnr9RikFxK+sw=="></script>
<!-- End jQuery-DateTimePicker JS from aa-gdpr -->
